==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libkom++/small-types.cc <==
// Priv_bits, Personal_flags, Who_info_old, Who_info_ident, Conf_type.
//
// $Id: small-types.cc,v 1.13 1995/11/28 22:34:44 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include <stdlib.h>
#include <time.h>

#include "time-utils.h"
#include "kom-types.h"
#include "priv-bits.h"
#include "personal-flags.h"
#include "who-info.h"
#include "who-info-old.h"
#include "who-info-ident.h"
#include "conf-type.h"
#include "prot-a-LyStr.h"


static int 
parse_bin_digit(LyStr &prot_a_str)
{
    switch(prot_a_str[0])
    {
    case '0':
	prot_a_str.remove_first(1);
	return 0;
    case '1':
	prot_a_str.remove_first(1);
	return 1;
    default:
	abort();
    }
}

// The Priv_bits class

Priv_bits::Priv_bits()
  : pb_wheel(0), pb_admin(0), pb_statistic(0), pb_create_pers(1), 
    pb_create_conf(1), pb_change_name(1), pb_extern_gw(0)
{
}

Priv_bits::Priv_bits(const Priv_bits&s)
  : pb_wheel(s.pb_wheel),
    pb_admin(s.pb_admin),
    pb_statistic(s.pb_statistic),
    pb_create_pers(s.pb_create_pers),
    pb_create_conf(s.pb_create_conf),
    pb_change_name(s.pb_change_name),
    pb_extern_gw(s.pb_extern_gw),
    flg8(s.flg8),
    flg9(s.flg9),
    flg10(s.flg10),
    flg11(s.flg11),
    flg12(s.flg12),
    flg13(s.flg13),
    flg14(s.flg14),
    flg15(s.flg15),
    flg16(s.flg16)
{
}

const Priv_bits &Priv_bits::operator =(const Priv_bits &s)
{
    pb_wheel = s.pb_wheel;
    pb_admin = s.pb_admin;
    pb_statistic = s.pb_statistic;
    pb_create_pers = s.pb_create_pers;
    pb_create_conf = s.pb_create_conf;
    pb_change_name = s.pb_change_name;
    pb_extern_gw = s.pb_extern_gw;
    flg8 = s.flg8;
    flg9 = s.flg9;
    flg10 = s.flg10;
    flg11 = s.flg11;
    flg12 = s.flg12;
    flg13 = s.flg13;
    flg14 = s.flg14;
    flg15 = s.flg15;
    flg16 = s.flg16;
    return *this;
}

Priv_bits
parse_priv_bits(LyStr &prot_a_str)
{
    Priv_bits res;

    while (prot_a_str.strlen() > 0 && prot_a_str[0] == ' ')
	prot_a_str.remove_first(1);

    res.pb_wheel = parse_bin_digit(prot_a_str);
    res.pb_admin = parse_bin_digit(prot_a_str);
    res.pb_statistic = parse_bin_digit(prot_a_str);
    res.pb_create_pers = parse_bin_digit(prot_a_str);
    res.pb_create_conf = parse_bin_digit(prot_a_str);
    res.pb_change_name = parse_bin_digit(prot_a_str);
    res.pb_extern_gw = parse_bin_digit(prot_a_str);
    res.flg8 = parse_bin_digit(prot_a_str);
    res.flg9 = parse_bin_digit(prot_a_str);
    res.flg10 = parse_bin_digit(prot_a_str);
    res.flg11 = parse_bin_digit(prot_a_str);
    res.flg12 = parse_bin_digit(prot_a_str);
    res.flg13 = parse_bin_digit(prot_a_str);
    res.flg14 = parse_bin_digit(prot_a_str);
    res.flg15 = parse_bin_digit(prot_a_str);
    res.flg16 = parse_bin_digit(prot_a_str);

    return res;
}

bool
Priv_bits::wheel() const
{
    return (bool) pb_wheel;
}

bool
Priv_bits::admin() const
{
    return (bool) pb_admin;
}

bool
Priv_bits::statistic() const
{
    return (bool) pb_statistic;
}

bool
Priv_bits::create_pers() const
{
    return (bool) pb_create_pers;
}

bool
Priv_bits::create_conf() const
{
    return (bool) pb_create_conf;
}

bool
Priv_bits::change_name() const
{
    return (bool) pb_change_name;
}

bool
Priv_bits::extern_gw() const
{
    return (bool) pb_extern_gw;
}

// The Personal_flags class

Personal_flags::Personal_flags()
  : pf_unread_is_secret(0)
{
}

Personal_flags::Personal_flags(const Personal_flags&s)
  :pf_unread_is_secret(s.pf_unread_is_secret)
{
}

const Personal_flags &Personal_flags::operator =(const Personal_flags &s)
{
    pf_unread_is_secret = s.pf_unread_is_secret;
    return *this;
}
bool
Personal_flags::unread_is_secret() const
{
    return (bool) pf_unread_is_secret;
}

Personal_flags
parse_personal_flags(LyStr &prot_a_str)
{
    Personal_flags res;

    while (prot_a_str.strlen() > 0 && prot_a_str[0] == ' ')
	prot_a_str.remove_first(1);

    res.pf_unread_is_secret = parse_bin_digit(prot_a_str);
    res.flg2 = parse_bin_digit(prot_a_str);
    res.flg3 = parse_bin_digit(prot_a_str);
    res.flg4 = parse_bin_digit(prot_a_str);
    res.flg5 = parse_bin_digit(prot_a_str);
    res.flg6 = parse_bin_digit(prot_a_str);
    res.flg7 = parse_bin_digit(prot_a_str);
    res.flg8 = parse_bin_digit(prot_a_str);

    return res;
}

Who_info_old::Who_info_old()
    : person(0), working_conference(0)
{
}

Who_info_old::Who_info_old(const Who_info_old &w)
    : person(w.person), what_am_i_doing(w.what_am_i_doing),
      working_conference(w.working_conference)
{
}

const Who_info_old &Who_info_old::operator =(const Who_info_old &w)
{
    person = w.person;
    what_am_i_doing = w.what_am_i_doing;
    working_conference = w.working_conference;
    return *this;
}

Who_info_ident::Who_info_ident()
    : person(0), working_conference(0), session_no(0)
{
}

Who_info_ident::Who_info_ident(const Who_info_ident &w)
    : person(w.person), what_am_i_doing(w.what_am_i_doing),
      username(w.username), ident_user(w.ident_user),
      hostname(w.hostname), working_conference(w.working_conference),
      session_no(w.session_no)
{
}

const Who_info_ident &
Who_info_ident::operator =(const Who_info_ident &w)
{
    person = w.person;
    what_am_i_doing = w.what_am_i_doing;
    username = w.username;
    ident_user = w.ident_user;
    hostname = w.hostname;
    working_conference = w.working_conference;
    session_no = w.session_no;
    return *this;
}


// ================================================================


Conf_type::Conf_type()
    : rd_prot(false),
      original(false),
      secret(false),
      letter_box(false)
{
}

Conf_type::Conf_type(const Conf_type&c)
    : rd_prot(c.rd_prot),
      original(c.original),
      secret(c.secret),
      letter_box(c.letter_box)
{
}

Conf_type::Conf_type(bool protect,
		     bool orig,
		     bool secr,
		     bool letterbox)
    : rd_prot(protect),
      original(orig),
      secret(secr),
      letter_box(letterbox)
{
}


Conf_type &
Conf_type::operator =(const Conf_type &c)
{
    rd_prot = c.rd_prot;
    original = c.original;
    secret = c.secret;
    letter_box = c.letter_box;
    return *this;
}

bool
Conf_type::is_protected() const
{
    return rd_prot;
}

bool
Conf_type::is_original()  const
{
    return original;
}

bool
Conf_type::is_secret()    const
{
    return secret;
}

bool
Conf_type::is_letterbox() const
{
    return letter_box;
}


Conf_type 
parse_conf_type(prot_a_LyStr &prot_a_str)
{
    Conf_type res;

    while (prot_a_str.strlen() > 0 && prot_a_str[0] == ' ')
	prot_a_str.remove_first(1);

    res.rd_prot = (bool) parse_bin_digit(prot_a_str);
    res.original = (bool) parse_bin_digit(prot_a_str);
    res.secret = (bool) parse_bin_digit(prot_a_str);
    res.letter_box = (bool) parse_bin_digit(prot_a_str);

    return res;
}


// ================================================================


struct tm parse_time(prot_a_LyStr &prot_a_str)
{
    struct tm res;

    res.tm_sec = prot_a_str.stol();
    res.tm_min = prot_a_str.stol();
    res.tm_hour = prot_a_str.stol();
    res.tm_mday = prot_a_str.stol();
    res.tm_mon = prot_a_str.stol();
    res.tm_year = prot_a_str.stol();
    res.tm_wday = prot_a_str.stol();
    res.tm_yday = prot_a_str.stol();
    res.tm_isdst = prot_a_str.stol();

    return res;
}

bool
struct_tm_newer(const struct tm &a,
		const struct tm &b)
{
    // This code assumes that A and B are expressed in the same time zone.
    if (a.tm_year > b.tm_year)
	return true;
    if (a.tm_mon > b.tm_mon)
	return true;
    if (a.tm_mday > b.tm_mday)
	return true;
    if (a.tm_hour > b.tm_hour)
	return true;
    if (a.tm_min > b.tm_min)
	return true;
    if (a.tm_sec > b.tm_sec)
	return true;
    return false;
}

==> kom%2B%2B-0.7.post.6.tar.gz: kom++-0.7.post.6/libkom++/small-types.cc <==
// Priv_bits, Personal_flags, Who_info_old, Conf_type.
//
// $Id: small-types.cc,v 1.17 2005/04/05 21:13:39 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include <config.h>

#include "time-utils.h"
#include "kom-types.h"
#include "priv-bits.h"
#include "personal-flags.h"
#include "who-info-old.h"
#include "conf-type.h"
#include "prot-a-LyStr.h"


static int 
parse_bin_digit(LyStr &prot_a_str)
{
    switch(prot_a_str[0])
    {
    case '0':
	prot_a_str.remove_first(1);
	return 0;
    case '1':
	prot_a_str.remove_first(1);
	return 1;
    default:
	std::abort();
    }
}

// The Priv_bits class

Priv_bits::Priv_bits()
  : pb_wheel(0), pb_admin(0), pb_statistic(0), pb_create_pers(1), 
    pb_create_conf(1), pb_change_name(1), pb_extern_gw(0)
{
}

Priv_bits::Priv_bits(const Priv_bits&s)
  : pb_wheel(s.pb_wheel),
    pb_admin(s.pb_admin),
    pb_statistic(s.pb_statistic),
    pb_create_pers(s.pb_create_pers),
    pb_create_conf(s.pb_create_conf),
    pb_change_name(s.pb_change_name),
    pb_extern_gw(s.pb_extern_gw),
    flg8(s.flg8),
    flg9(s.flg9),
    flg10(s.flg10),
    flg11(s.flg11),
    flg12(s.flg12),
    flg13(s.flg13),
    flg14(s.flg14),
    flg15(s.flg15),
    flg16(s.flg16)
{
}

const Priv_bits &Priv_bits::operator =(const Priv_bits &s)
{
    pb_wheel = s.pb_wheel;
    pb_admin = s.pb_admin;
    pb_statistic = s.pb_statistic;
    pb_create_pers = s.pb_create_pers;
    pb_create_conf = s.pb_create_conf;
    pb_change_name = s.pb_change_name;
    pb_extern_gw = s.pb_extern_gw;
    flg8 = s.flg8;
    flg9 = s.flg9;
    flg10 = s.flg10;
    flg11 = s.flg11;
    flg12 = s.flg12;
    flg13 = s.flg13;
    flg14 = s.flg14;
    flg15 = s.flg15;
    flg16 = s.flg16;
    return *this;
}

Priv_bits
parse_priv_bits(LyStr &prot_a_str)
{
    Priv_bits res;

    while (prot_a_str.strlen() > 0 && prot_a_str[0] == ' ')
	prot_a_str.remove_first(1);

    res.pb_wheel = parse_bin_digit(prot_a_str);
    res.pb_admin = parse_bin_digit(prot_a_str);
    res.pb_statistic = parse_bin_digit(prot_a_str);
    res.pb_create_pers = parse_bin_digit(prot_a_str);
    res.pb_create_conf = parse_bin_digit(prot_a_str);
    res.pb_change_name = parse_bin_digit(prot_a_str);
    res.pb_extern_gw = parse_bin_digit(prot_a_str);
    res.flg8 = parse_bin_digit(prot_a_str);
    res.flg9 = parse_bin_digit(prot_a_str);
    res.flg10 = parse_bin_digit(prot_a_str);
    res.flg11 = parse_bin_digit(prot_a_str);
    res.flg12 = parse_bin_digit(prot_a_str);
    res.flg13 = parse_bin_digit(prot_a_str);
    res.flg14 = parse_bin_digit(prot_a_str);
    res.flg15 = parse_bin_digit(prot_a_str);
    res.flg16 = parse_bin_digit(prot_a_str);

    return res;
}

bool
Priv_bits::wheel() const
{
    return pb_wheel;
}

bool
Priv_bits::admin() const
{
    return pb_admin;
}

bool
Priv_bits::statistic() const
{
    return pb_statistic;
}

bool
Priv_bits::create_pers() const
{
    return pb_create_pers;
}

bool
Priv_bits::create_conf() const
{
    return pb_create_conf;
}

bool
Priv_bits::change_name() const
{
    return pb_change_name;
}

bool
Priv_bits::extern_gw() const
{
    return pb_extern_gw;
}

// The Personal_flags class

Personal_flags::Personal_flags()
  : pf_unread_is_secret(0)
{
}

Personal_flags::Personal_flags(const Personal_flags&s)
  :pf_unread_is_secret(s.pf_unread_is_secret)
{
}

const Personal_flags &Personal_flags::operator =(const Personal_flags &s)
{
    pf_unread_is_secret = s.pf_unread_is_secret;
    return *this;
}
bool
Personal_flags::unread_is_secret() const
{
    return pf_unread_is_secret;
}

Personal_flags
parse_personal_flags(LyStr &prot_a_str)
{
    Personal_flags res;

    while (prot_a_str.strlen() > 0 && prot_a_str[0] == ' ')
	prot_a_str.remove_first(1);

    res.pf_unread_is_secret = parse_bin_digit(prot_a_str);
    res.flg2 = parse_bin_digit(prot_a_str);
    res.flg3 = parse_bin_digit(prot_a_str);
    res.flg4 = parse_bin_digit(prot_a_str);
    res.flg5 = parse_bin_digit(prot_a_str);
    res.flg6 = parse_bin_digit(prot_a_str);
    res.flg7 = parse_bin_digit(prot_a_str);
    res.flg8 = parse_bin_digit(prot_a_str);

    return res;
}

Who_info_old::Who_info_old()
    : person(0), working_conference(0)
{
}

Who_info_old::Who_info_old(const Who_info_old &w)
    : person(w.person), what_am_i_doing(w.what_am_i_doing),
      working_conference(w.working_conference)
{
}

const Who_info_old &Who_info_old::operator =(const Who_info_old &w)
{
    person = w.person;
    what_am_i_doing = w.what_am_i_doing;
    working_conference = w.working_conference;
    return *this;
}

// ================================================================


Conf_type::Conf_type()
    : rd_prot(false),
      original(false),
      secret(false),
      letter_box(false)
{
}

Conf_type::Conf_type(const Conf_type&c)
    : rd_prot(c.rd_prot),
      original(c.original),
      secret(c.secret),
      letter_box(c.letter_box)
{
}

Conf_type::Conf_type(bool protect,
		     bool orig,
		     bool secr,
		     bool letterbox)
    : rd_prot(protect),
      original(orig),
      secret(secr),
      letter_box(letterbox)
{
}


Conf_type &
Conf_type::operator =(const Conf_type &c)
{
    rd_prot = c.rd_prot;
    original = c.original;
    secret = c.secret;
    letter_box = c.letter_box;
    return *this;
}

bool
Conf_type::is_protected() const
{
    return rd_prot;
}

bool
Conf_type::is_original()  const
{
    return original;
}

bool
Conf_type::is_secret()    const
{
    return secret;
}

bool
Conf_type::is_letterbox() const
{
    return letter_box;
}


Conf_type 
parse_conf_type(prot_a_LyStr &prot_a_str)
{
    Conf_type res;

    while (prot_a_str.strlen() > 0 && prot_a_str[0] == ' ')
	prot_a_str.remove_first(1);

    res.rd_prot = parse_bin_digit(prot_a_str);
    res.original = parse_bin_digit(prot_a_str);
    res.secret = parse_bin_digit(prot_a_str);
    res.letter_box = parse_bin_digit(prot_a_str);

    return res;
}


// ================================================================


struct std::tm parse_time(prot_a_LyStr &prot_a_str)
{
    struct std::tm res;

    res.tm_sec = prot_a_str.stol();
    res.tm_min = prot_a_str.stol();
    res.tm_hour = prot_a_str.stol();
    res.tm_mday = prot_a_str.stol();
    res.tm_mon = prot_a_str.stol();
    res.tm_year = prot_a_str.stol();
    res.tm_wday = prot_a_str.stol();
    res.tm_yday = prot_a_str.stol();
    res.tm_isdst = prot_a_str.stol();

    return res;
}

bool
struct_tm_newer(const struct std::tm &a,
		const struct std::tm &b)
{
    // This code assumes that A and B are expressed in the same time zone.
    if (a.tm_year > b.tm_year)
	return true;
    if (a.tm_year < b.tm_year)
	return false;

    if (a.tm_mon > b.tm_mon)
	return true;
    if (a.tm_mon < b.tm_mon)
	return false;

    if (a.tm_mday > b.tm_mday)
	return true;
    if (a.tm_mday < b.tm_mday)
	return false;

    if (a.tm_hour > b.tm_hour)
	return true;
    if (a.tm_hour < b.tm_hour)
	return false;

    if (a.tm_min > b.tm_min)
	return true;
    if (a.tm_min < b.tm_min)
	return false;

    if (a.tm_sec > b.tm_sec)
	return true;
    if (a.tm_sec < b.tm_sec)
	return false;

    return false;
}
